SystemOrganization addCategory: #'OB-Filesystem-Core'!
SystemOrganization addCategory: #'OB-Filesystem-Commands'!
SystemOrganization addCategory: #'OB-Filesystem-Tests'!

TestResource subclass: #OBDirectoryResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Tests'!

!OBDirectoryResource methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 12:39'!
dataDir
	^ FSDiskFilesystem imageDirectory / self dataDirName! !

!OBDirectoryResource methodsFor: 'as yet unclassified' stamp: 'cwp 11/28/2003 22:44'!
dataDirName
	^ 'obtest'! !

!OBDirectoryResource methodsFor: 'as yet unclassified' stamp: 'cwp 10/8/2009 22:48'!
setUp
	| dir delta |
	dir := self dataDir.
	dir ensureDirectory.
	#(alpha beta gamma) do: 
		[:filename |
		(dir / filename) writeStreamDo: [:s | s nextPutAll: filename]].
	delta := dir / 'delta'.
	delta ensureDirectory.
	(delta / 'epsilon') ensureDirectory! !

!OBDirectoryResource methodsFor: 'as yet unclassified' stamp: 'cwp 10/8/2009 23:31'!
tearDown
	| dir |
	dir := self dataDir.
	(dir / 'delta' / 'epsilon') delete.
	(dir / 'delta') delete.
	#(alpha beta gamma) do: [:ea | (dir / ea) delete]! !

OBBrowserTest subclass: #OBFilesystemBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Tests'!

!OBFilesystemBrowserTest class methodsFor: 'as yet unclassified' stamp: 'cwp 12/17/2003 15:09'!
resources
	^ Array with: OBDirectoryResource! !

!OBFilesystemBrowserTest methodsFor: 'configuration' stamp: 'cwp 10/8/2009 23:34'!
browserClass
	^ OBFilesystemBrowser! !

!OBFilesystemBrowserTest methodsFor: 'constants' stamp: 'cwp 10/9/2009 00:12'!
epsilonNode
	^ OBFilesystemNode on: OBDirectoryResource current dataDir / 'delta' / 'epsilon'! !

!OBFilesystemBrowserTest methodsFor: 'constants' stamp: 'cwp 10/9/2009 00:06'!
node
	^ OBDirectoryNode onReference: OBDirectoryResource current dataDir! !

!OBFilesystemBrowserTest methodsFor: 'testing' stamp: 'cwp 12/17/2003 15:19'!
testInitialDisplay
	self listMorphs size = 1.
	self assertListAt: 1 contains: #(alpha beta gamma delta).
	self assertTextIs: ''.
	! !

!OBFilesystemBrowserTest methodsFor: 'testing' stamp: 'cwp 10/9/2009 00:10'!
testJumpToEpsilon
	| node |
	node := self epsilonNode.
	model jumpTo: node.
	self assertListAt: 1 contains: #(alpha beta gamma delta).
	self assertListAt: 2 contains: #(epsilon).
	self assertCurrentItemIs: 'epsilon'.! !

!OBFilesystemBrowserTest methodsFor: 'testing' stamp: 'cwp 10/15/2009 16:09'!
testMenuItems
	self select: 'alpha'.
	self assertMenuContains: 'delete...'! !

!OBFilesystemBrowserTest methodsFor: 'testing' stamp: 'cwp 12/17/2003 17:01'!
testSelectAlpha
	self select: 'alpha'.
	self assertListAt: 1 contains: #(alpha beta gamma delta).
	self assertTextIs: 'alpha'! !

OBCommandTest subclass: #OBCmdDeleteFileTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Tests'!

!OBCmdDeleteFileTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 16:08'!
factory
	^ OBCmdDeleteFile! !

!OBCmdDeleteFileTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 21:10'!
test04IsActiveOnFiles
	| node |
	node := OBFileNode on: (FSDiskFilesystem imageDirectory / 'foo').
	self assert: (self isActiveOn: node for: self).
	! !

!OBCmdDeleteFileTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 21:11'!
test05IsActiveOnDirectories
	| node |
	node := OBFileNode on: (FSDiskFilesystem imageDirectory).
	self assert: (self isActiveOn: node for: self).
	! !

!OBCmdDeleteFileTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 21:12'!
test06IsEnabledOnFiles
	| node |
	node := OBFileNode on: (FSDiskFilesystem imageDirectory / 'foo').
	self assert: (self isEnabledOn: node for: self).
	! !

!OBCmdDeleteFileTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 21:13'!
test07IsDisabledOnDirectories
	| node |
	node := OBFileNode on: (FSDiskFilesystem imageDirectory).
	self deny: (self isEnabledOn: node for: self).
	! !

OBNode subclass: #OBFilesystemNode
	instanceVariableNames: 'reference'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Core'!

OBFilesystemNode subclass: #OBDirectoryNode
	instanceVariableNames: 'directory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Core'!

!OBDirectoryNode class methodsFor: 'instance creation' stamp: 'cwp 10/9/2009 23:39'!
default
	^ self on: (FSReference defaultDirectory)! !

!OBDirectoryNode class methodsFor: 'initializing' stamp: 'cwp 5/27/2004 12:33'!
initialize
	OBBrowser registerFileBrowser! !

!OBDirectoryNode class methodsFor: 'instance creation' stamp: 'cwp 10/9/2009 23:39'!
root
	^ self on: (FSDiskFilesystem current root)! !

!OBDirectoryNode methodsFor: 'comparing' stamp: 'cwp 1/31/2004 14:59'!
= other
	^ self path = other path! !

!OBDirectoryNode methodsFor: 'children' stamp: 'cwp 10/8/2009 23:52'!
directories
	^ reference entries 
		select: [:entry | entry isDirectory and: [self shouldDisplay: entry]]
		thenCollect: [:entry | OBDirectoryNode onReference: entry]
	! !

!OBDirectoryNode methodsFor: 'private' stamp: 'cwp 11/28/2003 21:57'!
directory: aFileDirectory
	directory _ aFileDirectory! !

!OBDirectoryNode methodsFor: 'private' stamp: 'cwp 10/9/2009 00:01'!
displayEntry: aReference on: aStream
	| entry |
	entry := (FileDirectory on: aReference pathString) directoryEntry.
	aStream nextPutAll: (entry at: 1).
	aStream nextPutAll: ' - '.
	aStream nextPutAll: (entry at: 5) asString, ' bytes'.
	aStream cr.! !

!OBDirectoryNode methodsFor: 'children' stamp: 'cwp 10/9/2009 00:02'!
files
	^ reference entries
		select: [:ref | ref isFile and: [self shouldDisplay: ref]]
		thenCollect: [:ref | OBFileNode onReference: ref]
	! !

!OBDirectoryNode methodsFor: 'comparing' stamp: 'cwp 1/31/2004 14:59'!
hash
	^ self path hash! !

!OBDirectoryNode methodsFor: 'testing' stamp: 'cwp 10/15/2009 21:27'!
isDirectory
	^ true! !

!OBDirectoryNode methodsFor: 'public' stamp: 'cwp 10/8/2009 23:57'!
name
	^ reference basename! !

!OBDirectoryNode methodsFor: 'private' stamp: 'cwp 12/15/2003 21:37'!
nodeForEntry: anEntry
	^ (anEntry at: 4)
		ifTrue: [OBDirectoryNode on: (directory directoryNamed: (anEntry at: 1))]
		ifFalse: [OBFileNode on: (directory fullNameFor: (anEntry at: 1))]! !

!OBDirectoryNode methodsFor: 'accessing' stamp: 'cwp 10/9/2009 00:22'!
path
	^ reference path! !

!OBDirectoryNode methodsFor: 'private' stamp: 'cwp 10/8/2009 23:45'!
shouldDisplay: aReference
	^ aReference basename first ~= $.! !

!OBDirectoryNode methodsFor: 'public' stamp: 'cwp 10/9/2009 00:01'!
text
	| entry |
	entry := (FileDirectory on: reference pathString) directoryEntry.
	^ String streamContents: [:stream |
			stream 
				nextPutAll: 'Directory: '; 
				nextPutAll: (reference pathString); cr;
				nextPutAll: 'Created: '; nextPutAll: (entry at: 2) asString; cr;
				nextPutAll: 'Modified: '; nextPutAll: (entry at: 3) asString; cr;
				nextPutAll: 'Size: '; nextPutAll: (entry at: 5) asString; cr;
				cr; nextPutAll: '----------'; cr.

			reference entries do: [:e | self displayEntry: e on: stream]

	]! !

!OBDirectoryNode methodsFor: 'private' stamp: 'cwp 12/6/2003 17:43'!
textForDirectory: aFilename
	| entry |
	entry _ directory entryAt: aFilename.
	^ String streamContents: [:stream |
			stream 
				nextPutAll: 'Directory: '; 
				nextPutAll: (directory fullNameFor: aFilename); cr;
				nextPutAll: 'Created: '; nextPutAll: (entry at: 2) asString; cr;
				nextPutAll: 'Modified: '; nextPutAll: (entry at: 3) asString; cr;
				nextPutAll: 'Size: '; nextPutAll: (entry at: 5) asString; cr;
				cr; nextPutAll: '----------'; cr.

			directory entries do: [:e | self displayEntry: e on: stream]

	]! !

OBFilesystemNode subclass: #OBFileNode
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Core'!

!OBFileNode methodsFor: 'comparing' stamp: 'cwp 1/31/2004 14:58'!
= other
	^ self path = other path! !

!OBFileNode methodsFor: 'public' stamp: 'cwp 2/3/2004 22:30'!
actions
	^ Array with: (self action: #delete withLabel: 'delete')! !

!OBFileNode methodsFor: 'actions' stamp: 'cwp 3/14/2004 17:17'!
delete
	FileDirectory deleteFilePath: path.
	self signalDeletion.! !

!OBFileNode methodsFor: 'comparing' stamp: 'cwp 1/31/2004 14:58'!
hash
	^ self path hash! !

!OBFileNode methodsFor: 'testing' stamp: 'cwp 10/15/2009 21:27'!
isFile
	^ true! !

!OBFileNode methodsFor: 'public' stamp: 'cwp 10/9/2009 00:02'!
name
	^ reference basename! !

!OBFileNode methodsFor: 'public' stamp: 'cwp 10/9/2009 00:06'!
openFile
	^ FileStream oldFileNamed: reference pathString! !

!OBFileNode methodsFor: 'public' stamp: 'cwp 10/9/2009 23:34'!
text
	| file text |
	file := self openFile.
	file ifNil: [^ 'Error opening file'].
	file binary.
	text := file contentsOfEntireFile asString.
	file close.
	^ text! !

!OBFileNode methodsFor: 'public' stamp: 'cwp 10/15/2009 21:58'!
text: aText
	reference writeStreamDo: 
		[:out | 
		out 
			nextPutAll: aText asString;
			truncate]! !

!OBFilesystemNode class methodsFor: 'as yet unclassified' stamp: 'cwp 10/8/2009 23:40'!
on: aReference
	^ aReference isDirectory
		ifTrue: [OBDirectoryNode onReference: aReference]
		ifFalse: [OBFileNode onReference: aReference]! !

!OBFilesystemNode class methodsFor: 'as yet unclassified' stamp: 'cwp 10/8/2009 23:39'!
onReference: aReference
	^ self new setReference: aReference! !

!OBFilesystemNode methodsFor: 'ancestry' stamp: 'cwp 10/10/2009 00:49'!
isDescendantOf: aNode
	^ aNode path = self path or: [aNode path contains: self path]! !

!OBFilesystemNode methodsFor: 'testing' stamp: 'cwp 10/15/2009 21:27'!
isDirectory
	^ false! !

!OBFilesystemNode methodsFor: 'testing' stamp: 'cwp 10/15/2009 21:27'!
isFile
	^ false! !

!OBFilesystemNode methodsFor: 'accessing' stamp: 'cwp 10/9/2009 00:21'!
path
	^ reference path! !

!OBFilesystemNode methodsFor: 'accessing' stamp: 'cwp 10/10/2009 00:59'!
pathString
	^ reference pathString! !

!OBFilesystemNode methodsFor: 'initialize-release' stamp: 'cwp 10/8/2009 23:44'!
setReference: aReference
	reference := aReference! !

OBBrowser subclass: #OBFilesystemBrowser
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Core'!

!OBFilesystemBrowser class methodsFor: 'auto opening' stamp: 'cwp 10/9/2009 23:42'!
browseFilesystem
	^ self openRoot: OBDirectoryNode root selection: OBDirectoryNode default! !

!OBFilesystemBrowser class methodsFor: 'configuration' stamp: 'cwp 10/8/2009 23:37'!
defaultMetaNode
	| directory file |
	directory := OBMetaNode named: 'Directory'.
	file := OBMetaNode named: 'File'.
	directory 
		childAt: #directories put: directory;
		childAt: #files put: file.
	^ directory! !

!OBFilesystemBrowser class methodsFor: 'configuration' stamp: 'cwp 10/9/2009 23:30'!
defaultRootNode
	^ OBDirectoryNode onReference: (FSDiskFilesystem current root)! !

!OBFilesystemBrowser class methodsFor: 'configuration' stamp: 'cwp 10/15/2009 00:11'!
defaultSelection
	^ OBDirectoryNode onReference: (FSDiskFilesystem imageDirectory)! !

!OBFilesystemBrowser class methodsFor: 'initialize-release' stamp: 'cwp 10/9/2009 23:41'!
initialize
	^ self registerFileBrowser! !

!OBFilesystemBrowser class methodsFor: 'instance creation' stamp: 'cwp 10/9/2009 23:28'!
new
	^ self 
		metaNode: self defaultMetaNode
		root: self defaultRootNode
		selection: self defaultSelection
		panels: self panels! !

!OBFilesystemBrowser class methodsFor: 'configuration' stamp: 'cwp 10/10/2009 00:50'!
paneCount
	^ 3! !

!OBFilesystemBrowser class methodsFor: 'initialize-release' stamp: 'cwp 10/9/2009 23:40'!
registerFileBrowser
	TheWorldMenu registerOpenCommand: {'File Browser'. {self. #browseFileSystem}}.! !

!OBFilesystemBrowser methodsFor: 'commands' stamp: 'cwp 10/15/2009 16:09'!
cmdDeleteFile
	^ OBCmdDeleteFile! !

!OBFilesystemBrowser methodsFor: 'building' stamp: 'cwp 10/10/2009 00:54'!
defaultBackgroundColor
	^  Color r: 1.0 g: 1.0 b: 0.6! !

!OBFilesystemBrowser methodsFor: 'callbacks' stamp: 'cwp 10/10/2009 00:58'!
labelString
	^ self currentNode pathString! !

OBCommand subclass: #OBCmdDeleteFile
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Commands'!

!OBCmdDeleteFile methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 21:15'!
isActive
	^ true! !

!OBCmdDeleteFile methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 21:20'!
isEnabled
	^ target isFile! !

!OBCmdDeleteFile methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 16:08'!
label
	^ 'delete...'! !

TestCase subclass: #OBDirectoryNodeTest
	instanceVariableNames: 'node'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Tests'!

!OBDirectoryNodeTest class methodsFor: 'as yet unclassified' stamp: 'cwp 12/8/2003 22:32'!
resources
	^ Array with: OBDirectoryResource! !

!OBDirectoryNodeTest methodsFor: 'data' stamp: 'cwp 11/28/2003 22:47'!
dataDir
	^ OBDirectoryResource current dataDir! !

!OBDirectoryNodeTest methodsFor: 'running' stamp: 'cwp 10/8/2009 23:55'!
setUp
	node := OBDirectoryNode onReference: self dataDir.! !

!OBDirectoryNodeTest methodsFor: 'testing' stamp: 'cwp 12/17/2003 15:01'!
testDirectoryNodes
	| children |
	children _ node directories collect: [:n | n name].
	self assert: children = #(delta)
	! !

!OBDirectoryNodeTest methodsFor: 'testing' stamp: 'cwp 12/17/2003 14:49'!
testFileNodes
	| children |
	children _ node files.
	self assert: (children collect: [:n | n name]) = #(alpha beta gamma)
	! !

!OBDirectoryNodeTest methodsFor: 'testing' stamp: 'cwp 12/15/2003 21:39'!
testName
	self assert: node name = 'obtest'! !

!OBDirectoryNodeTest methodsFor: 'testing' stamp: 'cwp 12/15/2003 21:39'!
testText
	self assert: (node text endsWith: '
----------
alpha - 5 bytes
beta - 4 bytes
delta - 0 bytes
gamma - 5 bytes
')
! !

TestCase subclass: #OBFileNodeEditTest
	instanceVariableNames: 'node'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Tests'!

!OBFileNodeEditTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 12:45'!
createFile
	self dataFile writeStreamDo: [:out | out nextPutAll: 'omega']! !

!OBFileNodeEditTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 12:44'!
dataFile
	^ OBDirectoryResource current dataDir / 'omega'! !

!OBFileNodeEditTest methodsFor: 'as yet unclassified' stamp: 'cwp 12/15/2003 21:40'!
setUp
	self createFile.
	node _ OBFileNode on: self dataFile.
	! !

!OBFileNodeEditTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 12:50'!
tearDown
	self dataFile delete! !

!OBFileNodeEditTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/15/2009 12:49'!
testAcceptText
	| contents |
	node text: 'foo'.
	contents := (self dataFile readStreamDo: [:in | in contents]) asString.
	self assert: contents = 'foo'! !

TestCase subclass: #OBFileNodeTest
	instanceVariableNames: 'node notification'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Filesystem-Tests'!

!OBFileNodeTest class methodsFor: 'as yet unclassified' stamp: 'cwp 12/8/2003 22:32'!
resources
	^ Array with: OBDirectoryResource! !

!OBFileNodeTest methodsFor: 'running' stamp: 'cwp 10/15/2009 12:39'!
dataFile
	^ OBDirectoryResource current dataDir / 'alpha'! !

!OBFileNodeTest methodsFor: 'callbacks' stamp: 'cwp 1/23/2004 23:15'!
notification: aNotification
	notification _ aNotification! !

!OBFileNodeTest methodsFor: 'running' stamp: 'cwp 12/15/2003 21:40'!
setUp
	node _ OBFileNode on: self dataFile.! !

!OBFileNodeTest methodsFor: 'running' stamp: 'cwp 10/15/2009 12:44'!
tearDown
	self dataFile writeStreamDo: [:out | out nextPutAll: 'alpha']
		! !

!OBFileNodeTest methodsFor: 'testing' stamp: 'cwp 12/15/2003 21:41'!
testName
	self assert: node name = 'alpha'! !

!OBFileNodeTest methodsFor: 'testing' stamp: 'cwp 12/15/2003 21:41'!
testText
	self assert: (node text = 'alpha')! !
OBDirectoryNode initialize!
OBFilesystemBrowser initialize!
